=============================
django.slds
=============================

.. image:: https://badge.fury.io/py/django-slds.png
    :target: https://badge.fury.io/py/django-slds

.. image:: https://travis-ci.org/jlantz/django-slds.png?branch=master
    :target: https://travis-ci.org/jlantz/django-slds

Django implementation of the Salesforce Lightning Design System

Documentation
-------------

The full documentation is at https://django-slds.readthedocs.org.

Quickstart
----------

Install django.slds::

    pip install django-slds

Then use it in a project::

    import django_slds

Features
--------

* TODO

Running Tests
--------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements_test.txt
    (myenv) $ python runtests.py

Credits
---------

Salesforce Lightning Design System Licenses
===========================================

* Source code is licensed under [BSD License Clause 2](http://opensource.org/licenses/BSD-2-Clause)
* All icons and images are licensed under [Creative Commons Attribution-NoDerivatives 4.0](http://creativecommons.org/licenses/by-nd/4.0/)
* The font is licensed under our [font license](https://www.lightningdesignsystem.com/assets/licenses/License-for-font.txt)


Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-djangopackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
